@@ -108,10 +108,10 @@ def deploy_assignment(base_name, INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT
     # Now we have the instructor token file. Let's get the student token file.
     total_ = res['total'][1]
     problems = []
-    # problems.append( dict(name='Total', description='', max_score=total_, optional='false') )
+    problems.append( dict(name='Unitgrade score', description='', max_score=total_, optional='false') )
     # for k, q in res['details'].items():
     #     problems.append(dict(name=q['title'], description='', max_score=q['possible'], optional='true'))
-    problems.append(dict(name="Autograding Total", description='The description (set in autolab.py)', max_score=total_, optional='false'))
+    # problems.append(dict(name="Autograding Total", description='The description (set in autolab.py)', max_score=total_, optional='false'))
     print(problems)
 
     sc = [('Total', res['total'][0])] + [(q['title'], q['obtained']) for k, q in res['details'].items()]
@@ -255,7 +255,7 @@ def format_autolab_json(data, indent=None):
         s = json.dumps(pres)
     print(s)
     # totals
-    scores = {"scores": {'Total score': data['total'][0] }} #, 'scoreboard': [data['total'][0]] }
+    scores = {"scores": {'Unitgrade score': data['total'][0] }} #, 'scoreboard': [data['total'][0]] }
     print( json.dumps(scores) )
 
     a = 234
